/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

define(["dojo/dom", "dojo/on", "com/ibm/mobile/phonegapshow/util"],
  function(dom, on, util) {
    //-------------------------------------------------------------------------
    // Acceleration
    //-------------------------------------------------------------------------
	var watchAccelId = null;

	/**
     * Set accelerometer status
     */
    var setAccelStatus = function(status) {
        dom.byId('accel_status').innerHTML = status;
    };
 
    /**
     * Get current acceleration
     */
    function getAccelerometerData() {
        console.log("getAccelerometerData()");

        // Stop accel if running
        stopAccel();

        // Success callback
        var success = function(a){
            dom.byId('x').innerHTML = util.roundNumber(a.x);
            dom.byId('y').innerHTML = util.roundNumber(a.y);
            dom.byId('z').innerHTML = util.roundNumber(a.z);
        };

        // Fail callback
        var fail = function(e){
            console.log("getAccelerometerData fail callback with error code "+e);
            setAccelStatus(Accelerometer.ERROR_MSG[e]);
        };

        // Make call
        var opt = {};
        navigator.accelerometer.getCurrentAcceleration(success, fail, opt);
    };
  
    /**
     * Start watching acceleration
     */
    var watchAccel = function() {
        console.log("watchAccel()");

        // Success callback
        var success = function(a){
            dom.byId('x').innerHTML = util.roundNumber(a.x);
            dom.byId('y').innerHTML = util.roundNumber(a.y);
            dom.byId('z').innerHTML = util.roundNumber(a.z);
            console.log("watchAccel success callback");
        };

        // Fail callback
        var fail = function(e){
            console.log("watchAccel fail callback with error code "+e);
            stopAccel();
            setAccelStatus(Accelerometer.ERROR_MSG[e]);
        };

        // Update acceleration every 1 sec
        var opt = {};
        opt.frequency = 1000;
        watchAccelId = navigator.accelerometer.watchAcceleration(success, fail, opt);

        setAccelStatus("Running");
    };

    /**
     * Stop watching the acceleration
     */
    var stopAccel = function() {
    	console.log("stopAccel()");
        setAccelStatus("Stopped");
        if (watchAccelId) {
            navigator.accelerometer.clearWatch(watchAccelId);
            watchAccelId = null;
        }
    };
	
	return {
		init: function() {
			console.log("initializeAccelerometerControls()");
			setAccelStatus("Stopped");
			on(dom.byId("getAccelBtn"), "click", getAccelerometerData);
			on(dom.byId("startAccelBtn"), "click", watchAccel);
			on(dom.byId("stopAccelBtn"), "click", stopAccel);
		}
	};
});
