/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

define(["dojo/dom", "dojo/on"],
  function(dom, on) {

    /**
     * Set audio status
     */
    var setAudioStatus = function(status) {
        dom.byId('audio_status').innerHTML = status;
    };

    /**
     * Set audio position
     */
    var setAudioPosition = function(position) {
        dom.byId('audio_position').innerHTML = position;
    };

    //-------------------------------------------------------------------------
    // Audio player
    //-------------------------------------------------------------------------
    var media1 = null;
    var media1Timer = null;
    var audioSrc = null;
	var recordSrc = "myRecording.mp3";
	
	var mediaStatus = Media.MEDIA_NONE;
	   
    /**
     * Play audio
     */
    
    function playDefaultAudio() {
    	console.log("playDefaultAudio()");
    	playAudio();
    }
    
    function playLocalAudio() {
	   console.log("playLocalAudio()");
	   var src;
	   if (navigator.userAgent.indexOf("Android") < 0) {
            src = "default/dojo/com/ibm/mobile/phonegapshow/audio/think.wav";
	   } else {
            src = "/android_asset/www/default/dojo/com/ibm/mobile/phonegapshow/audio/think.wav";
	   }
	   playAudio(src);
	}
    
    function playAudio(url) {
        console.log("playAudio()");
        console.log(" -- media="+media1);

        var src = "http://audio.ibeat.org/content/p1rj1s/p1rj1s_-_rockGuitar.mp3";
        
        if (url) {
            src = url;
        }

        console.log("Attempting to play: "+src);
        
        // Stop playing if src is different from currently playing source
        if (src != audioSrc) {
            if (media1 != null) {
                stopAudio();
                media1 = null;
            }
        }
        
        if(mediaStatus == Media.MEDIA_RUNNING) {
        	if (media1 != null) {
                stopAudio();
                media1 = null;
            }
        }

        if (media1 == null) {
            media1 = new Media(src,
                function() {
                    console.log("playAudio():Audio Success");
                },
                function(err) {
                    console.log("playAudio():Audio Error: "+err);
                    setAudioStatus("Error: " + err);
                },
                function(status) {
                    console.log("playAudio():Audio Status: "+status);
                    mediaStatus = status;
                    setAudioStatus(Media.MEDIA_MSG[status]);

                    // Code below should be removed, since the media1Timer was cleared in stopAudio - Bryan.
                    // If stopped, then stop getting current position
                    /*
                    if (Media.MEDIA_STOPPED == status) {
                        clearInterval(media1Timer);
                        media1Timer = null;
                    }
                    */
                });
        }
        audioSrc = src;
        dom.byId('audio_duration').innerHTML = "";
        // Play audio
        console.log("Starting playback");
        media1.play();
        if (media1Timer == null && media1.getCurrentPosition) {
            media1Timer = setInterval(
                function() {
                    media1.getCurrentPosition(
                        function(position) {
                            console.log("Pos="+position);
                            if (position > -1) {
                                setAudioPosition(position+" sec");
                            }
                        },
                        function(e) {
                            console.log("Error getting pos="+e);
                            setAudioPosition("Error: "+e);
                        }
                    );
                },
                1000
            );
        }

        // Get duration
        var counter = 0;
        var timerDur = setInterval(
            function() {
                counter = counter + 100;
                if (counter > 2000) {
                    clearInterval(timerDur);
                }
                var dur = media1.getDuration();
                if (dur > 0) {
                    clearInterval(timerDur);
                    dom.byId('audio_duration').innerHTML = dur + " sec";
                }
            }, 100);
    }

    /**
     * Pause audio playback
     */
    function pauseAudio() {
        console.log("pauseAudio()");
        if(mediaStatus != Media.MEDIA_RUNNING) {
        	alert('Cannot pause audio, because it\'s not running');
        	return;
        }
        if (media1) {
            media1.pause();
        }
    }

    /**
     * Stop audio
     */
    function stopAudio(shouldAlert) {
        console.log("stopAudio()");
        if(mediaStatus == Media.MEDIA_STOPPED) {
        	if(shouldAlert) {
        		alert('Audio is already stopped.');
        	}
        	return;
        }
        if (media1) {
            media1.stop();
        }
        clearInterval(media1Timer);
        media1Timer = null;
    }

    //-------------------------------------------------------------------------
    // Audio recorder
    //-------------------------------------------------------------------------
    var mediaRec = null;
    var recTime = 0;

    /**
     * Record audio
     */
    function recordAudio() {
        console.log("recordAudio()");
        console.log(" -- media="+mediaRec);
        
        if (media1 != null) {
            stopAudio();
            media1 = null;
        }
        
        function record() {
        	//navigator.notification.beep(1);
        	
			// Record audio
	        mediaRec.startRecord();

	        // Stop recording after 10 sec
	        recTime = 0;
	        var recInterval = setInterval(function() {
	            recTime = recTime + 1;
	            setAudioPosition(recTime+" sec");
	            if (recTime >= 10) {
	                clearInterval(recInterval);
	                if (mediaRec.stopAudioRecord){
	                    mediaRec.stopAudioRecord();
	                } else {
	                    mediaRec.stopRecord();
	                }
	                console.log("recordAudio(): stop");
	                navigator.notification.beep(1);
	            }
	        }, 1000);
		}
        
        if (mediaRec == null) {
        	var recAudioSuccess = function() {
        		console.log("recordAudio():Audio Success");
        	};
        	var recAudioError = function(err) {
        		console.log("recordAudio():Audio Error: "+err);
                setAudioStatus("Error: " + err);
        	};
        	var recAudioStatus = function(status) {
        		console.log("recordAudio():Audio Status: "+status);
                mediaStatus = status;
                setAudioStatus(Media.MEDIA_MSG[status]);
        	};
        	
        	if (navigator.userAgent.indexOf("Android") < 0) {
//				recordSrc = "default/dojo/com/ibm/mobile/phonegapshow/audio/myRecording.wav";
				var fsFail = function(error) {
		            console.log("Error creating file for iOS recording: ");
		            console.log(error);
		        };
				window.requestFileSystem(LocalFileSystem.TEMPORARY, 0, function(fileSystem) {
					fileSystem.root.getFile("iOSRecording.wav", {
						create: true, exclusive: false
					}, function(fileEntry) {
						console.log("File iOSRecording.wav created at " + fileEntry.fullPath);
						recordSrc = fileEntry.fullPath;
						mediaRec = new Media(recordSrc, recAudioSuccess, recAudioError, recAudioStatus);
						record();
					}, fsFail);
				}, fsFail);
			} else {
				mediaRec = new Media(recordSrc, recAudioSuccess, recAudioError, recAudioStatus);
				record();
			}
        } else {
        	record();
        }
    }

    /**
     * Play back recorded audio
     */
    function playRecording() {
        playAudio(recordSrc);
    }
    
    /**
     * Function to create a file for iOS recording
     */
    function getRecordSrc() {
        var fsFail = function(error) {
            console.log("error creating file for iOS recording");
        };
        var gotFile = function(file) {
            recordSrc = file.fullPath;
            //console.log("recording Src: " + recordSrc);
        };
        var gotFS = function(fileSystem) {
            fileSystem.root.getFile("iOSRecording.wav", {create: true}, gotFile, fsFail);
        };
        window.requestFileSystem(LocalFileSystem.TEMPORARY, 0, gotFS, fsFail);
    }

	
	return {
		init: function() {
			console.log("initializeAudioControls()");
			
			on(dom.byId("playAudioBtn"), "click", playDefaultAudio);
			on(dom.byId("playLocalAudioBtn"), "click", playLocalAudio);
			on(dom.byId("pauseAudioBtn"), "click", pauseAudio);
			on(dom.byId("stopAudioBtn"), "click", function() { stopAudio(true); });
			on(dom.byId("recordAudioBtn"), "click", recordAudio);
			on(dom.byId("playRecordingBtn"), "click", playRecording);
		}
	};
});
