/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

define(["dojo/dom", "dojo/on"],
  function(dom, on) {

    //-------------------------------------------------------------------------
    // Notifications
    //-------------------------------------------------------------------------

    function beep(){
        navigator.notification.beep(3);
    };

    function vibrate(){
      navigator.notification.vibrate(2000);
    };

    function alertDialog(message, title, button) {
        console.log("alertDialog()");
        navigator.notification.alert(message,
            function(){
                console.log("Alert dismissed.");
            },
            title, button);
        console.log("After alert");
    };

    function confirmDialog(message, title, buttons) {
        navigator.notification.confirm(message,
            function(r) {
                console.log("You selected " + r);
                alert("You selected " + (buttons.split(","))[r-1]);
            },
            title,
            buttons);
    };
	
	return {
		init: function() {
			console.log("initializeNotificationControls()");
			
			// disable "beep" on iOS. To enable it, you need to put the "beep.wav" file 
			// directly under the "www" folder of the native Xcode project.
			on(dom.byId("beepBtn"), "click", beep);
			if (navigator.userAgent.indexOf("Android") < 0) {
				dom.byId("beepBtn").disabled = "disabled";
			}
			
			on(dom.byId("vibrateBtn"), "click", vibrate);
			on(dom.byId("alertBtn"), "click", function(){alertDialog('You pressed alert.', 'Alert Dialog', 'Continue');});
			on(dom.byId("confirmDialogBtn"), "click", function(){confirmDialog('You pressed confirm.', 'Confirm Dialog', 'Yes,No,Maybe');});
			on(dom.byId("alertBuiltInBtn"), "click", function(){alert('You pressed alert.');});
			on(dom.byId("confirmBuiltInBtn"), "click", function(){confirm('You selected confirm');});
			on(dom.byId("promptBtn"), "click", function(){prompt('This is a prompt.', 'Default value');});
		}
	};
});
