/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

/* JavaScript content from dojo/com/ibm/mobile/phonegapshow/structure.js in folder common */

define(["dojo/_base/lang"], function(lang){
	lang.getObject("com.ibm.mobile.phonegapshow.structure", true);
	
	var miscellaneousViewHtml = "views/misc.html";
	if (-1 <  navigator.userAgent.toLowerCase().indexOf("android")) {
		miscellaneousViewHtml = "views/misc-android.html";
	}
	
	var THRESHOLD_WIDTH = 600;
	com.ibm.mobile.phonegapshow.structure = {
		layout: {
			threshold: THRESHOLD_WIDTH, // threshold for layout change
			leftPane: {
				hidden: (window.innerWidth < THRESHOLD_WIDTH) ? true : false,
						currentView: null
			},
			rightPane: {
				hidden: false,
				currentView: null
			},
			getViewHolder: function(id) {
				if (id === "navigation")
					return (window.innerWidth < THRESHOLD_WIDTH) ? "rightPane" : "leftPane";
				else
					return "rightPane";
			},
			setCurrentView: function(id) {
				var holder = this.getViewHolder(id);
				this[holder].currentView = id;
			}
		},
		demos: [{
			id: "controls",
			label: "Controls",
			iconBase: "images/navigation_list_all_29.png",
			views: [{
				id: "info",
				speclevel: "0",
				iconPos: "29,0,29,29",
				title: "Info",
				shortTitle: "Info",
				demourl: "views/info.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/info.js",
				jsSrc: "doc/src/info.js.txt"
			}, {
				id: "accelerometer",
				speclevel: "0",
				iconPos: "232,0,29,29",
				title: "Accelerometer",
				shortTitle: "Accelerometer",
				demourl: "views/accelerometer.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/accelerometer.js",
				jsSrc: "doc/src/accelerometer.js.txt"
			}, {
				id: "audio",
				speclevel: "0",
				iconPos: "58,0,29,29",
				title: "Audio Play/Record",
				shortTitle: "Audio",
				demourl: "views/audio.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/audio.js",
				jsSrc: "doc/src/audio.js.txt"
			}, {
				id: "camera",
				speclevel: "0",
				iconPos: "58,0,29,29",
				title: "Camera",
				shortTitle: "Camera",
				demourl: "views/camera.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/camera.js",
				jsSrc: "doc/src/camera.js.txt"
			}, {
				id: "compass",
				speclevel: "0",
				iconPos: "174,0,29,29",
				title: "Compass",
				shortTitle: "Compass",
				demourl: "views/compass.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/compass.js",
				jsSrc: "doc/src/compass.js.txt"
			}, {
				id: "contacts",
				speclevel: "0",
				iconPos: "203,0,29,29",
				title: "Contacts",
				shortTitle: "Contacts",
				demourl: "views/contacts.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/contacts.js",
				jsSrc: "doc/src/contacts.js.txt"
			}, {
				id: "events",
				speclevel: "0",
				iconPos: "0,0,29,29",
				title: "Events",
				shortTitle: "Events",
				demourl: "views/events.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/events.js",
				jsSrc: "doc/src/events.js.txt"
			}, {
				id: "location",
				speclevel: "0",
				iconPos: "174,0,29,29",
				title: "Location",
				shortTitle: "Location",
				demourl: "views/location.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/location.js",
				jsSrc: "doc/src/location.js.txt"				
			}, {
				id: "localstorage",
				speclevel: "0",
				iconPos: "29,0,29,29",
				title: "Local Storage",
				shortTitle: "Local Storage",
				demourl: "views/localstorage.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/localstorage.js",
				jsSrc: "doc/src/localstorage.js.txt"
			}, {
				id: "misc",
				speclevel: "0",
				iconPos: "290,0,29,29",
				title: "Miscellaneous content",
				shortTitle: "Miscellaneous",
				demourl: miscellaneousViewHtml
			}, {
				id: "notification",
				speclevel: "0",
				iconPos: "145,0,29,29",
				title: "Notification/Dialogs",
				shortTitle: "Dialogs",
				demourl: "views/notification.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/notification.js",
				jsSrc: "doc/src/notification.js.txt"
			}, {
				id: "websql",
				speclevel: "0",
				iconPos: "29,0,29,29",
				title: "Web SQL",
				shortTitle: "Web SQL",
				demourl: "views/websql.html",
				jsmodule: "dojo/com/ibm/mobile/phonegapshow/websql.js",
				jsSrc: "doc/src/websql.js.txt"
			}]
		}],
		/* Below are internal views. */
		_views: [{
			id: 'source',
			title: 'Source',
			type: 'source'
		}, {
			id: 'welcome',
			title: 'Welcome',
            shortTitle: 'Welcome'
		}, {
			id: 'navigation',
			title: 'Showcase',
			type: 'navigation',
			back: ''
		}],
		/* data model for tracking view loading */
		load: {
			loaded: 0,
			target: 0 //target number of views that should be loaded
		}
	};
	return com.ibm.mobile.phonegapshow.structure;
});